@@ -63,10 +63,10 @@ namespace Banshee.Collection.Database
         private static DatabaseTrackModelProvider<DatabaseTrackInfo> provider;
 
         public static DatabaseTrackModelProvider<DatabaseTrackInfo> Provider {
-            get { return provider ?? provider = new DatabaseTrackModelProvider<DatabaseTrackInfo> (ServiceManager.DbConnection); }
+            get { return provider ?? (provider = new DatabaseTrackModelProvider<DatabaseTrackInfo> (ServiceManager.DbConnection)); }
         }
 
-        private bool? artist_changed = null, album_changed = null;
+        private bool artist_changed = false, album_changed = false;
         private bool uri_fields_dirty = false;
         
         public DatabaseTrackInfo () : base ()
@@ -106,7 +106,16 @@ namespace Banshee.Collection.Database
             }
             return TrackEqual (this, db_track);
         }
-        
+
+        public override string ArtworkId {
+            get {
+                if (PrimarySource != null && PrimarySource.TrackArtworkIdHandler != null) {
+                    return PrimarySource.TrackArtworkIdHandler (this);
+                }
+                return base.ArtworkId;
+            }
+        }
+
         public static bool TrackEqual (DatabaseTrackInfo a, DatabaseTrackInfo b)
         {
             return a != null && b != null && 
@@ -215,6 +224,11 @@ namespace Banshee.Collection.Database
         }
 
         [VirtualDatabaseColumn ("Name", "CoreArtists", "ArtistID", "ArtistID")]
+        protected string ArtistNameField {
+            get { return ArtistName; }
+            set { base.ArtistName = value; }
+        }
+
         public override string ArtistName {
             get { return base.ArtistName; }
             set {
@@ -222,16 +236,17 @@ namespace Banshee.Collection.Database
                 if (value == null)
                     return;
 
-                if (!IsCompilation) {
-                    AlbumArtist = value;
-                }
-
                 base.ArtistName = value;
-                artist_changed = artist_changed != null;
+                artist_changed = true;
             }
         }
 
         [VirtualDatabaseColumn ("Title", "CoreAlbums", "AlbumID", "AlbumID")]
+        protected string AlbumTitleField {
+            get { return AlbumTitle; }
+            set { base.AlbumTitle = value; }
+        }
+
         public override string AlbumTitle {
             get { return base.AlbumTitle; }
             set {
@@ -240,11 +255,16 @@ namespace Banshee.Collection.Database
                     return;
 
                 base.AlbumTitle = value;
-                album_changed = album_changed != null;
+                album_changed = true;
             }
         }
 
         [VirtualDatabaseColumn ("ArtistName", "CoreAlbums", "AlbumID", "AlbumID")]
+        protected string AlbumArtistField {
+            get { return AlbumArtist; }
+            set { base.AlbumArtist = value; }
+        }
+
         public override string AlbumArtist {
             get { return base.AlbumArtist; }
             set {
@@ -253,16 +273,21 @@ namespace Banshee.Collection.Database
                     return;
 
                 base.AlbumArtist = value;
-                album_changed = album_changed != null;
+                album_changed = true;
             }
         }
         
         [VirtualDatabaseColumn ("IsCompilation", "CoreAlbums", "AlbumID", "AlbumID")]
+        protected bool IsCompilationField {
+            get { return IsCompilation; }
+            set { base.IsCompilation = value; }
+        }
+
         public override bool IsCompilation {
             get { return base.IsCompilation; }
             set {
                 base.IsCompilation = value;
-                album_changed = album_changed != null;
+                album_changed = true;
             }
         }
         
@@ -305,7 +330,7 @@ namespace Banshee.Collection.Database
         [DatabaseColumn ("Uri")]
         protected string UriField {
             get {
-                if (uri_fields_dirty) {
+                if (uri_fields_dirty && Uri != null && PrimarySource != null) {
                     PrimarySource.UriToFields (Uri, out uri_type, out uri_field);
                     uri_fields_dirty = false;
                 }
@@ -322,7 +347,7 @@ namespace Banshee.Collection.Database
         [DatabaseColumn ("UriType")]
         protected TrackUriType UriType {
             get {
-                if (uri_fields_dirty) {
+                if (uri_fields_dirty && Uri != null && PrimarySource != null) {
                     PrimarySource.UriToFields (Uri, out uri_type, out uri_field);
                     uri_fields_dirty = false;
                 }
@@ -506,6 +531,16 @@ namespace Banshee.Collection.Database
             get { return external_id; }
             set { external_id = value; }
         }
+
+        private object external_object;
+        public override object ExternalObject {
+            get {
+                if (external_id > 0 && external_object == null && PrimarySource != null && PrimarySource.TrackExternalObjectHandler != null) {
+                    external_object = PrimarySource.TrackExternalObjectHandler (this);
+                }
+                return external_object;
+            }
+        }
         
         [DatabaseColumn ("LastPlayedStamp")]
         public override DateTime LastPlayed {
