@@ -28,11 +28,14 @@
 
 using System;
 using Gtk;
+using Hyena.Gui;
 
 namespace Banshee.Gui.TrackEditor
 {
     public class RangeEntry : HBox, IEditorField
     {
+        public delegate void RangeOrderClosure (RangeEntry entry);
+        
         public event EventHandler Changed;
     
         private SpinButton from_entry;
@@ -45,11 +48,25 @@ namespace Banshee.Gui.TrackEditor
             get { return to_entry; }
         }
     
-        public RangeEntry (string rangeLabel)
+        public RangeEntry (string rangeLabel) : this (rangeLabel, null, null)
         {
+        }
+    
+        public RangeEntry (string rangeLabel, RangeOrderClosure orderClosure, string orderTooltip)
+        {
+            AutoOrderButton auto_order_button;
+        
             PackStart (from_entry = new SpinButton (0, 99, 1), true, true, 0);
             PackStart (new Label (rangeLabel), false, false, 6);
             PackStart (to_entry = new SpinButton (0, 99, 1), true, true, 0);
+            if (orderClosure != null) {
+                PackStart (auto_order_button = new AutoOrderButton (), false, false, 1);
+                auto_order_button.Clicked += delegate { orderClosure (this); };
+                if (orderTooltip != null) {
+                    TooltipSetter.Set (TooltipSetter.CreateHost (), auto_order_button, orderTooltip);
+                }
+            }
+            
             ShowAll ();
             
             from_entry.WidthChars = 2;
@@ -59,6 +76,17 @@ namespace Banshee.Gui.TrackEditor
             to_entry.ValueChanged += OnChanged;
         }
         
+        private class AutoOrderButton : Button
+        {
+            public AutoOrderButton () 
+            {
+                Image image = new Image (Gtk.Stock.SortAscending, IconSize.Menu);
+                Add (image);
+                Relief = ReliefStyle.None;
+                image.Show ();
+            }
+        }
+        
         private void OnChanged (object o, EventArgs args)
         {
             EventHandler handler = Changed;
